@@ -15,6 +15,12 @@ from .messaging.messaging import Messaging
 from .merchant_fulfillment.merchant_fulfillment import MerchantFulfillment
 
 ##### DO NOT DELETE ########## INSERT IMPORT HERE #######
+from .catalog_items.catalog_items import CatalogItems
+    
+from .product_type_definitions.product_type_definitions import ProductTypeDefinitions
+    
+from .listings_items.listings_items import ListingsItems
+    
 from .vendor_transaction_status.vendor_transaction_status import VendorTransactionStatus
     
 from .vendor_shipments.vendor_shipments import VendorShipments
@@ -71,6 +77,12 @@ __all__ = [
     "FulfillmentInbound",
     "MerchantFulfillment",
     ##### DO NOT DELETE ########## INSERT TITLE HERE #######
+    "CatalogItems",
+    
+    "ProductTypeDefinitions",
+    
+    "ListingsItems",
+    
     "VendorTransactionStatus",
     
     "VendorShipments",
